@@ -19,7 +19,6 @@ CONF_AREA = "area"
 CONF_AREA_OVERRIDE = "areaoverride"
 CONF_AUTO_DISCOVER = "autodiscover"
 CONF_CHANNEL = "channel"
-CONF_CHANNEL_CLASS = "class"
 CONF_CHANNEL_COVER = "channelcover"
 CONF_CHANNEL_TYPE = "type"
 CONF_CLOSE_PRESET = "close"
@@ -30,7 +29,6 @@ CONF_FADE = "fade"
 CONF_HIDDEN_ENTITY = "hidden"
 CONF_HOST = "host"
 CONF_JOIN = "join"
-CONF_LEVEL = "level"
 CONF_NAME = "name"
 CONF_NO_DEFAULT = "nodefault"
 CONF_NONE = "none"
@@ -53,7 +51,7 @@ ATTR_POSITION = "position"
 ATTR_TILT_POSITION = "tilt_position"
 
 DEFAULT_CHANNEL_TYPE = "light"
-DEFAULT_COVER_CHANNEL_CLASS = "shutter"
+DEFAULT_COVER_CLASS = "shutter"
 DEFAULT_NAME = "dynalite"
 DEFAULT_PORT = 12345
 DEFAULT_TEMPLATES = {
@@ -62,7 +60,7 @@ DEFAULT_TEMPLATES = {
     CONF_HIDDEN_ENTITY: {},
     CONF_TIME_COVER: {
         CONF_CHANNEL_COVER: "1",
-        CONF_CHANNEL_CLASS: DEFAULT_COVER_CHANNEL_CLASS,
+        CONF_DEVICE_CLASS: DEFAULT_COVER_CLASS,
         CONF_OPEN_PRESET: "1",
         CONF_CLOSE_PRESET: "2",
         CONF_STOP_PRESET: "4",
@@ -70,15 +68,15 @@ DEFAULT_TEMPLATES = {
         CONF_TILT_TIME: 0,
     },
 }
+DEFAULT_PRESETS = {
+    "1": {CONF_NAME: "On"},
+    "4": {CONF_NAME: "Off"},
+}
 
 EVENT_CHANNEL = "CHANNEL"
-EVENT_CONFIGURED = "CONFIGURED"
 EVENT_CONNECTED = "CONNECTED"
 EVENT_DISCONNECTED = "DISCONNECTED"
-EVENT_NEWPRESET = "NEWPRESET"
-EVENT_NEWCHANNEL = "NEWCHANNEL"
 EVENT_PRESET = "PRESET"
-EVENT_REQPRESET = "REQPRESET"
 
 # if a request for channel level didn't get acknowledge, when to retry
 # (subsequent retries will be 2x, 4x, 8x, etc.)
