@@ -17,7 +17,6 @@ from .const import (
     CONF_AREA_OVERRIDE,
     CONF_AUTO_DISCOVER,
     CONF_CHANNEL,
-    CONF_CHANNEL_CLASS,
     CONF_CHANNEL_COVER,
     CONF_CHANNEL_TYPE,
     CONF_CLOSE_PRESET,
@@ -46,6 +45,7 @@ from .const import (
     DEFAULT_CHANNEL_TYPE,
     DEFAULT_NAME,
     DEFAULT_PORT,
+    DEFAULT_PRESETS,
     DEFAULT_TEMPLATES,
     EVENT_CHANNEL,
     EVENT_CONNECTED,
@@ -70,18 +70,24 @@ class BridgeError(Exception):
     def __init__(self, message):
         """Initialize the exception."""
         self.message = message
+        super().__init__(message)
 
 
 class DynaliteDevices:
     """Manages a single Dynalite bridge."""
 
-    def __init__(self, loop=None, newDeviceFunc=None, updateDeviceFunc=None):
+    def __init__(self, loop=None, new_device_func=None, update_device_func=None):
         """Initialize the system."""
+        self.host = None
+        self.port = None
+        self.name = None
+        self.poll_timer = None
+        self.default_fade = None
         self.active = None
         self.auto_discover = None
         self.loop = loop
-        self.newDeviceFunc = newDeviceFunc
-        self.updateDeviceFunc = updateDeviceFunc
+        self.new_device_func = new_device_func
+        self.update_device_func = update_device_func
         self.configured = False
         self.connected = False
         self.added_presets = {}
@@ -93,7 +99,8 @@ class DynaliteDevices:
         self.timer_callbacks = set()
         self.template = {}
         self.area = {}
-        self._dynalite = Dynalite(broadcast_func=self.handleEvent,)
+        self.dynalite = Dynalite(broadcast_func=self.handle_event)
+        self.resetting = False
 
     async def async_setup(self):
         """Set up a Dynalite bridge based on host parameter in the config."""
@@ -101,7 +108,8 @@ class DynaliteDevices:
         if not self.loop:
             self.loop = asyncio.get_running_loop()
         # Run the dynalite object. Assumes self.configure() has been called
-        self.connected = await self._dynalite.connect(self.host, self.port)
+        self.resetting = False
+        self.connected = await self.dynalite.connect(self.host, self.port)
         return self.connected
 
     def configure(self, config):
@@ -109,7 +117,7 @@ class DynaliteDevices:
         LOGGER.debug("bridge async_configure - %s", config)
         self.configured = False
         # insert the global values
-        self.host = config[CONF_HOST]
+        self.host = config.get(CONF_HOST, "HOST")  # Default value for testing
         self.port = config.get(CONF_PORT, DEFAULT_PORT)
         self.name = config.get(CONF_NAME, f"{DEFAULT_NAME}-{self.host}")
         self.auto_discover = config.get(CONF_AUTO_DISCOVER, False)
@@ -130,7 +138,7 @@ class DynaliteDevices:
                     conf, DEFAULT_TEMPLATES[template][conf]
                 )
         # create default presets
-        config_presets = config.get(CONF_PRESET, {})
+        config_presets = config.get(CONF_PRESET, DEFAULT_PRESETS)
         default_presets = {}
         for preset in config_presets:
             cur_config = config_presets[preset]
@@ -164,6 +172,9 @@ class DynaliteDevices:
                     CONF_FADE: channel_config.get(
                         CONF_FADE, self.area[area][CONF_FADE]
                     ),
+                    CONF_CHANNEL_TYPE: channel_config.get(
+                        CONF_CHANNEL_TYPE, DEFAULT_CHANNEL_TYPE
+                    ),
                 }
             # add the entities implicitly defined by templates
             template = area_config.get(CONF_TEMPLATE)
@@ -177,9 +188,8 @@ class DynaliteDevices:
                     CONF_CLOSE_PRESET,
                     CONF_STOP_PRESET,
                 ]
-                conf_values = [CONF_CHANNEL_CLASS, CONF_DURATION, CONF_TILT_TIME]
+                conf_values = [CONF_DEVICE_CLASS, CONF_DURATION, CONF_TILT_TIME]
                 conf_channels = [CONF_CHANNEL_COVER]
-
                 for conf in self.template[template]:
                     conf_value = area_config.get(conf, self.template[template][conf])
                     if conf in conf_presets:
@@ -204,6 +214,7 @@ class DynaliteDevices:
                     else:
                         assert conf in conf_values
                         self.area[area][conf] = conf_value
+                area_config[CONF_NO_DEFAULT] = True
             # Default presets
             if not area_config.get(CONF_NO_DEFAULT, False):
                 for preset in default_presets:
@@ -213,11 +224,11 @@ class DynaliteDevices:
             self.area[area][CONF_CHANNEL] = area_channels
             # now register the channels and presets and ask for initial status if needed
             if self.active in [CONF_ACTIVE_INIT, CONF_ACTIVE_ON]:
-                self._dynalite.request_area_preset(area)
+                self.dynalite.request_area_preset(area)
             for channel in area_channels:
                 self.create_channel_if_new(area, channel)
                 if self.active in [CONF_ACTIVE_INIT, CONF_ACTIVE_ON]:
-                    self._dynalite.request_channel_level(area, channel)
+                    self.dynalite.request_channel_level(area, channel)
             for preset in area_presets:
                 self.create_preset_if_new(area, preset)
 
@@ -227,8 +238,8 @@ class DynaliteDevices:
         # register the time covers
         self.register_time_covers()
         # callback for all devices
-        if self.newDeviceFunc and self.waiting_devices:
-            self.newDeviceFunc(self.waiting_devices)
+        if self.new_device_func and self.waiting_devices:
+            self.new_device_func(self.waiting_devices)
             self.waiting_devices = []
         self.configured = True
 
@@ -246,7 +257,7 @@ class DynaliteDevices:
                 new_device.set_device(
                     2, self.added_presets[area][area_config[CONF_ROOM_OFF]]
                 )
-                self.registerNewDevice("switch", new_device, False)
+                self.register_new_device("switch", new_device, False)
 
     def register_time_covers(self):
         """Register the time covers from three presets and a channel each."""
@@ -275,15 +286,15 @@ class DynaliteDevices:
                 else:
                     channel_device = DynaliteBaseDevice(area, self)
                 new_device.set_device(4, channel_device)
-                self.registerNewDevice("cover", new_device, False)
+                self.register_new_device("cover", new_device, False)
 
-    def registerNewDevice(self, category, device, hidden):
+    def register_new_device(self, category, device, hidden):
         """Register a new device and group all the ones prior to CONFIGURED event together."""
         # after initial configuration, every new device gets sent on its own. The initial ones are bunched together
         if not hidden:
             if self.configured:
-                if self.newDeviceFunc:
-                    self.newDeviceFunc([device])
+                if self.new_device_func:
+                    self.new_device_func([device])
             else:  # send all the devices together when configured
                 self.waiting_devices.append(device)
 
@@ -292,38 +303,37 @@ class DynaliteDevices:
         """Return whether bridge is available."""
         return self.connected
 
-    def updateDevice(self, device):
+    def update_device(self, device):
         """Update one or more devices."""
-        if self.updateDeviceFunc:
-            self.updateDeviceFunc(device)
+        if self.update_device_func:
+            self.update_device_func(device)
 
-    def handleEvent(self, event=None):
+    def handle_event(self, event=None):
         """Handle all events."""
-        LOGGER.debug("handleEvent - type=%s event=%s" % (event.eventType, event.data))
-        if event.eventType == EVENT_CONNECTED:
+        LOGGER.debug("handle_event - type=%s event=%s", event.event_type, event.data)
+        if event.event_type == EVENT_CONNECTED:
             LOGGER.debug("Received CONNECTED message")
             self.connected = True
-            self.updateDevice(CONF_ALL)
-        elif event.eventType == EVENT_DISCONNECTED:
+            self.update_device(CONF_ALL)
+        elif event.event_type == EVENT_DISCONNECTED:
             LOGGER.debug("Received DISCONNECTED message")
             self.connected = False
-            self.updateDevice(CONF_ALL)
-        elif event.eventType == EVENT_PRESET:
+            self.update_device(CONF_ALL)
+        elif event.event_type == EVENT_PRESET:
             LOGGER.debug("Received PRESET message")
             self.handle_preset_selection(event)
-        elif event.eventType == EVENT_CHANNEL:
+        elif event.event_type == EVENT_CHANNEL:
             LOGGER.debug("Received PRESET message")
             self.handle_channel_change(event)
         else:
             LOGGER.debug(
-                "Received unknown message type=%s data=%s", event.eventType, event.data
+                "Received unknown message type=%s data=%s", event.event_type, event.data
             )
-        return
 
     def ensure_area(self, area):
         """Configure a default area if it is not yet in config."""
         if area not in self.area:
-            LOGGER.debug(f"adding area {area} that is not in config")
+            LOGGER.debug("adding area %s that is not in config", area)
             self.area[area] = {CONF_NAME: f"Area {area}", CONF_FADE: self.default_fade}
 
     def create_preset_if_new(self, area, preset):
@@ -353,7 +363,7 @@ class DynaliteDevices:
         hidden = area_config[CONF_PRESET][preset].get(CONF_HIDDEN_ENTITY, False)
         new_device = DynalitePresetSwitchDevice(area, preset, self,)
         new_device.set_level(0)
-        self.registerNewDevice("switch", new_device, hidden)
+        self.register_new_device("switch", new_device, hidden)
         if area not in self.added_presets:
             self.added_presets[area] = {}
         self.added_presets[area][preset] = new_device
@@ -372,18 +382,17 @@ class DynaliteDevices:
             # Unknown and no autodiscover
             return
         # Update all the preset devices
-        for curPresetInArea in self.added_presets[area]:
-            device = self.added_presets[area][curPresetInArea]
-            if curPresetInArea == preset:
+        for cur_preset_in_area in self.added_presets[area]:
+            device = self.added_presets[area][cur_preset_in_area]
+            if cur_preset_in_area == preset:
                 device.set_level(1)
             else:
                 device.set_level(0)
-            self.updateDevice(device)
+            self.update_device(device)
         # If active is set to full, query all channels in the area
         if self.active == CONF_ACTIVE_ON:
             for channel in self.area[area].get(CONF_CHANNEL, {}):
-                LOGGER.debug("XXX - querying area %s channel %s", area, channel)
-                self._dynalite.request_channel_level(area, channel)
+                self.dynalite.request_channel_level(area, channel)
 
     def create_channel_if_new(self, area, channel):
         """Register a new channel."""
@@ -419,10 +428,10 @@ class DynaliteDevices:
         hidden = channel_config.get(CONF_HIDDEN_ENTITY, False)
         if channel_type == "light":
             new_device = DynaliteChannelLightDevice(area, channel, self,)
-            self.registerNewDevice("light", new_device, hidden)
+            self.register_new_device("light", new_device, hidden)
         elif channel_type == "switch":
             new_device = DynaliteChannelSwitchDevice(area, channel, self,)
-            self.registerNewDevice("switch", new_device, hidden)
+            self.register_new_device("switch", new_device, hidden)
         else:
             LOGGER.info("unknown chnanel type %s - ignoring", channel_type)
             return
@@ -446,26 +455,26 @@ class DynaliteDevices:
         if action == CONF_ACTION_REPORT:
             actual_level = (255 - event.data[CONF_ACT_LEVEL]) / 254
             target_level = (255 - event.data[CONF_TRGT_LEVEL]) / 254
-            channelToSet = self.added_channels[area][channel]
-            channelToSet.update_level(actual_level, target_level)
-            self.updateDevice(channelToSet)
+            channel_to_set = self.added_channels[area][channel]
+            channel_to_set.update_level(actual_level, target_level)
+            self.update_device(channel_to_set)
         elif action == CONF_ACTION_CMD:
             target_level = (255 - event.data[CONF_TRGT_LEVEL]) / 254
             # when there is only a "set channel level" command, assume that this is both the actual and the target
             actual_level = target_level
-            channelToSet = self.added_channels[area][channel]
-            channelToSet.update_level(actual_level, target_level)
-            self.updateDevice(channelToSet)
+            channel_to_set = self.added_channels[area][channel]
+            channel_to_set.update_level(actual_level, target_level)
+            self.update_device(channel_to_set)
         elif action == CONF_ACTION_STOP:
             if channel == CONF_ALL:
                 for channel in self.added_channels.get(area, {}):
-                    channelToSet = self.added_channels[area][channel]
-                    channelToSet.stop_fade()
-                    self.updateDevice(channelToSet)
+                    channel_to_set = self.added_channels[area][channel]
+                    channel_to_set.stop_fade()
+                    self.update_device(channel_to_set)
             else:
-                channelToSet = self.added_channels[area][channel]
-                channelToSet.stop_fade()
-                self.updateDevice(channelToSet)
+                channel_to_set = self.added_channels[area][channel]
+                channel_to_set.stop_fade()
+                self.update_device(channel_to_set)
         else:
             LOGGER.error("unknown action for channel change %s", action)
 
@@ -473,7 +482,7 @@ class DynaliteDevices:
         """Add a listener to the timer and start if needed."""
         self.timer_callbacks.add(callback_func)
         if not self.timer_active:
-            self.loop.call_later(1, self.timer_func)
+            self.loop.call_later(self.poll_timer, self.timer_func)
             self.timer_active = True
 
     def remove_timer_listener(self, callback_func):
@@ -482,22 +491,26 @@ class DynaliteDevices:
 
     def timer_func(self):
         """Call callbacks and either schedule timer or stop."""
-        if self.timer_callbacks:
+        if self.timer_callbacks and not self.resetting:
             for callback in self.timer_callbacks:
                 self.loop.call_soon(callback)
-            self.loop.call_later(1, self.timer_func)
+            self.loop.call_later(self.poll_timer, self.timer_func)
         else:
             self.timer_active = False
 
     def set_channel_level(self, area, channel, level, fade):
         """Set the level for a channel."""
         fade = self.area[area][CONF_CHANNEL][channel][CONF_FADE]
-        self._dynalite.set_channel_level(area, channel, level, fade)
+        self.dynalite.set_channel_level(area, channel, level, fade)
 
     def select_preset(self, area, preset):
         """Select a preset in an area."""
         fade = self.area[area][CONF_PRESET][preset][CONF_FADE]
-        self._dynalite.select_preset(area, preset, fade)
+        self.dynalite.select_preset(area, preset, fade)
+
+    def get_area_name(self, area):
+        """Return the name of an area."""
+        return self.area[area][CONF_NAME]
 
     def get_channel_name(self, area, channel):
         """Return the name of a channel."""
@@ -523,14 +536,29 @@ class DynaliteDevices:
         """Return the class for a blind."""
         return self.area[area][CONF_DEVICE_CLASS]
 
-    def getMasterArea(self, area):
+    def get_cover_duration(self, area):
+        """Return the class for a blind."""
+        return self.area[area][CONF_DURATION]
+
+    def get_cover_tilt_duration(self, area):
+        """Return the class for a blind."""
+        return self.area[area][CONF_TILT_TIME]
+
+    def get_master_area(self, area):
         """Get the master area when combining entities from different Dynet areas to the same area."""
         if area not in self.area:
-            LOGGER.error("getMasterArea - we should not get here")
-            raise BridgeError("getMasterArea - area " + str(area) + "is not in config")
+            LOGGER.error("get_master_area - we should not get here")
+            raise BridgeError(f"get_master_area - area {area} is not in config")
         area_config = self.area[area]
         master_area = area_config[CONF_NAME]
         if CONF_AREA_OVERRIDE in area_config:
             override_area = area_config[CONF_AREA_OVERRIDE]
             master_area = override_area if override_area.lower() != CONF_NONE else ""
         return master_area
+
+    async def async_reset(self):
+        """Reset the connections and timers."""
+        self.resetting = True
+        await self.dynalite.async_reset()
+        while self.timer_active:
+            await asyncio.sleep(1)
