@@ -23,7 +23,7 @@ class DynaliteBaseDevice:  # Deriving from Object so it doesn't override the ent
     @property
     def get_master_area(self):
         """Get the master area when combining entities from different Dynet areas to the same area."""
-        return self._bridge.getMasterArea(self._area)
+        return self._bridge.get_master_area(self._area)
 
     def add_listener(self, listener):
         """Add a listener for changes."""
@@ -89,8 +89,8 @@ class DynaliteMultiDevice(DynaliteBaseDevice):
         self._devices[devnum] = device
         device.add_listener(self.listener)
         if self.available:
-            self._bridge.updateDevice(self)
+            self._bridge.update_device(self)
 
     def listener(self, device, stop_fade):
         """Update the device since its internal devices changed."""
-        self._bridge.updateDevice(self)
+        self._bridge.update_device(self)
