@@ -2,19 +2,15 @@
 import json
 
 
-class DynetEvent(object):
+class DynetEvent:
     """Class to represent an event on the Dynet network."""
 
-    def __init__(self, eventType=None, message=None, data={}):
+    def __init__(self, event_type=None, message=None, data=None):
         """Initialize the event."""
-        self.eventType = eventType.upper() if eventType else None
+        self.event_type = event_type.upper() if event_type else None
         self.msg = message
         self.data = data
 
-    def toJson(self):
-        """Convert to JSON."""
-        return json.dumps(self.__dict__)
-
     def __repr__(self):
         """Print the event."""
         return json.dumps(self.__dict__)
